@echo off
rem This batch file allows you to combine the components
rem for the L_H INI-file.
rem If you like you can easily add other components.
rem The structure is quite straight forward:
rem 1: Select a primary language
rem 2: Add alternate user-interface languages if you like
rem 3: L_H (default) settings
rem 4: Select one or more element-attribute files.
rem
rem After agreeing on the selected components a (new) INI-file
rem will be composed.
rem If you prepare additional INI-file components please make
rem sure Ctrl-Z (end-of-file) characters are not at the
rem end of each file.
rem
rem Feel free to translate this file
rem
rem Filename defaults for the files that can be selected:
rem ppppItcc, where
rem pppp = Program name (L_H_)
rem I    = just an I
rem t    = file type, where
rem        C = character set
rem        D = HTML definitions
rem        I = User interface
rem        S = Program setup parameters
rem cc   = Contry code, where
rem        NL = Dutch
rem        UK = English
rem

:inistart
SET elat=
SET elattxt=
SET prim=
SET primlan=
SET chr=
SET chrtxt=
SET sec=
SET seclan=
SET stptxt=
SET stp=
cls
echo : L_H INI-setup
echo : 
echo : This batchfile will compose a new L_H.INI file.
echo : The current INI-file will be replaced.
echo : 
echo : Select primary user-interface language:
echo : Type: U=English N=Dutch   Q=Cancel
choice Select primary user-interface language qun
IF errorlevel 3 goto primlannl
IF errorlevel 2 goto primlanuk
goto cancel

:primlannl
SET primlan=Dutch
set prim=l_h_iinl
goto sec1

:primlanuk
SET primlan=English
SET prim=l_h_iiuk
goto sec1

:sec1
echo : 
echo : Select secundary user-interface language(s):
if  NOT "%seclan%"=="" echo : Current secundary user-interface language: %seclan%
echo : Type: U=English N=Dutch  X=continue  Q=Cancel
choice Select secundary user-interface language qxun
IF errorlevel 4 goto seclannl
IF errorlevel 3 goto seclanuk
IF errorlevel 2 goto setup
goto cancel

:seclannl
SET seclan=%seclan% Dutch
SET sec=%sec+l_h_iinl
goto sec1

:seclanuk
SET seclan=%seclan% English
SET sec=%sec+l_h_iiuk
goto sec1

:setup
echo : 
echo : Select (default) settings to use:
if  NOT "%stptxt%"=="" echo : Current setup: %stptxt%
echo : Type: D=Default setup
choice Select setup qxd
IF errorlevel 3 goto setupd
IF errorlevel 2 goto entity
goto cancel

:setupd
SET stptxt=%stptxt% Defaults
SET stp=%stp+l_h_isuk
goto setup

:entity
echo : 
echo : Select charactersets to support:
if  NOT "%chrtxt%"=="" echo : Current charactersets: %chrtxt%
echo : Type: 1=ISO 8859-1  X=Continue  Q=Cancel
choice Select characterset qx1
IF errorlevel 3 goto iso88591
IF errorlevel 2 goto cmnd1
goto cancel

:iso88591
SET chrtxt=%chrtxt% ISO 8859-1
SET chr=%chr+l_h_ici1
goto entity

:cmnd1
echo : 
echo : Select element/attribute definitions to use:
if  NOT "%elattxt%"=="" echo : Current element/attribute definitions: %elattxt%
echo : Type: U=English  P=Plain  N=Dutch  Q=Cancel
choice Select definition files qunp
IF errorlevel 4 goto cmddpl
IF errorlevel 3 goto cmddnl
IF errorlevel 2 goto cmdduk
goto cancel

:cmddpl
SET elattxt=%elattxt Plain
SET elat=%elat+l_h_idpl
goto copy1

:cmdduk
SET elattxt=%elattxt Standard Enlish
SET elat=%elat+l_h_iduk
goto copy1

:cmddnl
SET elattxt=%elattxt Standard Dutch
SET elat=%elat+l_h_idnl
goto copy1

:copy1
if  "%elat%"=="" goto nocmnd
if  "%prim%"=="" goto noprim
if  "%chr%"=="" goto nochr
echo : 
echo : Primary user-interface language: %primlan%
if  NOT "%seclan%"=="" echo : Secundary user-interface language: %seclan%
echo : Setup defaults: %stptxt%
echo : Characterset: %chrtxt%
echo : Element/attribute definition: %elattxt%
choice Is this what you want qyn
if  errorlevel 3 goto inistart
if  errorlevel 2 goto copy2
goto cancel

:copy2
echo : 
@COPY %prim%%sec%%stp%%chr%%elat% l_h.ini
echo : INI-file produced
goto exit

:nocmnd
echo : Element/attribute description missing
echo : At least one element/attribute definition is required
echo : No INI-file produced
goto exit

:noprim
echo : Primary language not specified
echo : At least one language should be available
echo : No INI-file produced
goto exit

:nochr
echo : Characterset not specified
echo : At least one characterset should be available
echo : No INI-file produced
goto exit

:cancel
echo : INI-file generation cancelled by the user

:exit
SET elat=
SET elattxt=
SET prim=
SET primlan=
SET chr=
SET chrtxt=
SET sec=
SET seclan=
SET stptxt=
SET stp=
